SystemOrganization addCategory: #'Collections-Tests-BitmapCharacterSet'!

TestCase subclass: #BitmapCharacterSetTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Collections-Tests-BitmapCharacterSet'!

!BitmapCharacterSetTest methodsFor: 'accessing' stamp: 'JAAyer 1/21/2011 16:45'!
absentCharacters
	"This returns the neighboring characters of each element of #characters, provided they
	are not also elements of #characters"

	| absentCharacters |

	absentCharacters := OrderedCollection new.
	self characters do: [:each | | asciiValue nextChar previousChar |
		(asciiValue := each asciiValue) > 0
			ifTrue: [
				previousChar := Character value: asciiValue - 1.
				(self characters includes: previousChar)
					ifFalse: [absentCharacters add: previousChar]].
		nextChar := Character value: asciiValue + 1.
		(self characters includes: nextChar)
			ifFalse: [absentCharacters add: nextChar]].
	^ absentCharacters asArray.! !

!BitmapCharacterSetTest methodsFor: 'accessing' stamp: 'JAAyer 1/20/2011 02:45'!
characterSetClass
	^ BitmapCharacterSet! !

!BitmapCharacterSetTest methodsFor: 'accessing' stamp: 'JAAyer 1/20/2011 00:46'!
characters
	^ #(0 50 100 200 255 256 500 1000) collect: [:each | Character value: each]! !

!BitmapCharacterSetTest methodsFor: 'accessing' stamp: 'JAAyer 1/20/2011 00:45'!
emptyCharacterSet
	^ self characterSetClass new! !

!BitmapCharacterSetTest methodsFor: 'accessing' stamp: 'JAAyer 1/20/2011 00:56'!
nonEmptyCharacterSet
	^ self characterSetClass newFrom: self characters! !

!BitmapCharacterSetTest methodsFor: 'tests' stamp: 'JAAyer 1/20/2011 00:44'!
testAdd
	| set |

	set := self emptyCharacterSet.
	self
		deny: (self characters anySatisfy: [:each | set includes: each]);
		assert: (self characters allSatisfy: [:each | (set add: each) == each]);
		assert: (self characters allSatisfy: [:each | set includes: each]).! !

!BitmapCharacterSetTest methodsFor: 'tests' stamp: 'JAAyer 1/20/2011 01:12'!
testCapacity
	self
		assert: (self characterSetClass new: 256) capacity = 256;
		assert: (self characterSetClass new: 257) capacity = 264;
		assert: (self characterSetClass new: 500) capacity = 504! !

!BitmapCharacterSetTest methodsFor: 'tests' stamp: 'JAAyer 1/20/2011 00:49'!
testDo
	| set enumerated |

	set := self emptyCharacterSet.
	enumerated := OrderedCollection new.

	set do: [:each | enumerated add: each].
	self assert: enumerated isEmpty.

	set addAll: self characters.
	set do: [:each | enumerated add: each].
	self assert: enumerated asArray = self characters asArray.! !

!BitmapCharacterSetTest methodsFor: 'tests' stamp: 'JAAyer 1/20/2011 01:12'!
testEquals
	self
		assert: self emptyCharacterSet = self emptyCharacterSet;
		assert: self nonEmptyCharacterSet = self nonEmptyCharacterSet;
		deny: self emptyCharacterSet = self nonEmptyCharacterSet;
		deny: self nonEmptyCharacterSet = self emptyCharacterSet! !

!BitmapCharacterSetTest methodsFor: 'tests' stamp: 'JAAyer 1/20/2011 01:11'!
testHash
	self
		assert: self emptyCharacterSet hash = self emptyCharacterSet hash;
		assert: self nonEmptyCharacterSet hash = self nonEmptyCharacterSet hash;
		deny: self emptyCharacterSet hash = self nonEmptyCharacterSet hash! !

!BitmapCharacterSetTest methodsFor: 'tests' stamp: 'JAAyer 1/21/2011 16:46'!
testIncludes
	| set |

	set := self emptyCharacterSet.
	self
		deny: (self characters anySatisfy: [:each | set includes: each]);
		deny: (self absentCharacters anySatisfy: [:each | set includes: each]).

	set addAll: self characters.
	self
		assert: (self characters allSatisfy: [:each | set includes: each]);
		deny: (self absentCharacters anySatisfy: [:each | set includes: each]).! !

!BitmapCharacterSetTest methodsFor: 'tests' stamp: 'JAAyer 1/20/2011 01:02'!
testNewFrom
	| set newSet |

	set := self characterSetClass newFrom: self characters.
	self
		assert: set class == self characterSetClass;
		assert: (self characters allSatisfy: [:each | set includes: each]).

	newSet := self characterSetClass newFrom: set.
	self
		assert: newSet = set;
		deny: newSet == set.! !

!BitmapCharacterSetTest methodsFor: 'tests' stamp: 'JAAyer 1/21/2011 16:50'!
testRemoveIfAbsent
	| set |

	set := self nonEmptyCharacterSet.
	self
		assert: (self absentCharacters allSatisfy: [:each | (set remove: each ifAbsent: [nil]) isNil]);
		assert: (self characters allSatisfy: [:each | (set remove: each ifAbsent: [nil]) = each]);
		deny: (self characters anySatisfy: [:each | set includes: each]);
		assert: (self characters allSatisfy: [:each | (set remove: each ifAbsent: [nil]) isNil]).! !
